import org.apache.spark.sql.Dataset;
import org.apache.spark.sql.Row;
import org.apache.spark.sql.SparkSession;
import org.apache.spark.sql.functions;
import org.apache.spark.storage.StorageLevel;

public class SparkCSVProducer {

    public static void main(String[] args){

        //Create and get Spark Session
        SparkSession spark = getSparkSession();

        //Load data from CSV
        Dataset<Row> csvDataFrame = loadDataFromCSV(spark);

        //Convert dataFrame to Json
        Dataset<Row> productInfoJson = convertToJsonDataFrame(csvDataFrame);

        //publish product data to Kafka
        publishToKaka(productInfoJson);

    }

    private static Dataset<Row> loadDataFromCSV(SparkSession spark) {
        Dataset<Row> df = spark.read()
                .format("csv")
                .option("header", "true")
                .load("src/main/resources/data.csv");
        df.show();
        return df;
    }

    private static SparkSession getSparkSession() {
        SparkSession spark = SparkSession.builder()
                .master("local")
                .appName("SparkCSVProducer")
                .getOrCreate();
        return spark;
    }

    private static Dataset<Row> convertToJsonDataFrame(Dataset<Row> productInfoDataFrame) {
        Dataset<Row> productInfoJson = productInfoDataFrame
                .withColumn("value", functions.to_json(functions.struct(functions.col("productId"),
                        functions.col("productName"), functions.col("productPrice"),
                        functions.col("deliveryStatus")))).alias("value").select("value")
                .persist(StorageLevel.MEMORY_AND_DISK());
        productInfoJson.show(false);
        return productInfoJson;
    }

    private static void publishToKaka(Dataset<Row> userCardInfoJson) {
        userCardInfoJson
                .write()
                .format("kafka")
                .option("kafka.bootstrap.servers", "localhost:9092")
                .option("topic", "ProductInfoTopic").save();
    }

}
